# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ESTNOISE_METADATA = Metadata(
    id="2c8a4ee6ccd87d75e1631dbf9205191f803cbb5f.boutiques",
    name="estnoise",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class EstnoiseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `estnoise(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_noise_file: OutputPathType
    """Output text file containing noise estimates"""


def estnoise(
    input_4d_data: InputPathType,
    spatial_sigma: float | None = None,
    temp_hp_sigma: float | None = None,
    temp_lp_sigma: float | None = None,
    runner: Runner | None = None,
) -> EstnoiseOutputs:
    """
    Estimate noise in 4D fMRI data.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FEAT
    
    Args:
        input_4d_data: Input 4D fMRI data (e.g., fmri_data.nii.gz).
        spatial_sigma: Spatial smoothing sigma.
        temp_hp_sigma: Temporal high-pass filter sigma.
        temp_lp_sigma: Temporal low-pass filter sigma.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EstnoiseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ESTNOISE_METADATA)
    cargs = []
    cargs.append("estnoise")
    cargs.append(execution.input_file(input_4d_data))
    if spatial_sigma is not None:
        cargs.append(str(spatial_sigma))
    if temp_hp_sigma is not None:
        cargs.append(str(temp_hp_sigma))
    if temp_lp_sigma is not None:
        cargs.append(str(temp_lp_sigma))
    ret = EstnoiseOutputs(
        root=execution.output_file("."),
        output_noise_file=execution.output_file("noise_estimate.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ESTNOISE_METADATA",
    "EstnoiseOutputs",
    "estnoise",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CCALC_METADATA = Metadata(
    id="a05d87fa78c6c1673017e42f1fb96f2c26608f02.boutiques",
    name="ccalc",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class CcalcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ccalc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def ccalc(
    expr: str,
    format_: str | None = None,
    runner: Runner | None = None,
) -> CcalcOutputs:
    """
    Command line calculator with formatted output options.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/ccalc.html
    
    Args:
        expr: Evaluate an expression specified on command line, return answer\
            and quit.
        format_: Format output in a nice form. Choose from 'double', 'nice',\
            'int', 'rint', 'cint', 'fint', or custom format string (e.g., %n.mf).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CcalcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CCALC_METADATA)
    cargs = []
    cargs.append("ccalc")
    if format_ is not None:
        cargs.extend([
            "-form",
            format_
        ])
    cargs.append("-eval")
    cargs.extend([
        "-eval",
        expr
    ])
    ret = CcalcOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CCALC_METADATA",
    "CcalcOutputs",
    "ccalc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TTOLOGP_METADATA = Metadata(
    id="ec7bd326f37ef20eb7460f2d41957799c29390d3.boutiques",
    name="ttologp",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class TtologpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ttologp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_logpvol: OutputPathType
    """Output volume for logp value"""


def ttologp(
    varsfile: InputPathType,
    cbsfile: InputPathType,
    dof: str,
    runner: Runner | None = None,
) -> TtologpOutputs:
    """
    Tool for computing logp.
    
    Author: Unknown
    
    Args:
        varsfile: Path to the vars file.
        cbsfile: Path to the cbs file.
        dof: Degree of freedom.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TtologpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TTOLOGP_METADATA)
    cargs = []
    cargs.append("ttologp")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(varsfile))
    cargs.append(execution.input_file(cbsfile))
    cargs.append(dof)
    ret = TtologpOutputs(
        root=execution.output_file("."),
        output_logpvol=execution.output_file("[OUTPUTVOL].nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TTOLOGP_METADATA",
    "TtologpOutputs",
    "ttologp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLSPLIT_METADATA = Metadata(
    id="0437d7a80ec1e0e35ca9e21fabd9655c69b443b2.boutiques",
    name="fslsplit",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslsplitOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslsplit(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfiles: OutputPathType | None
    """Output volumes/slices"""


def fslsplit(
    infile: InputPathType,
    output_basename: str | None = "vol",
    separation_z: bool = False,
    runner: Runner | None = None,
) -> FslsplitOutputs:
    """
    Split a 4D image into separate volumes or a 3D image into separate slices.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        infile: Input image (e.g. img.nii.gz).
        output_basename: Output basename (default: vol).
        separation_z: Separate images in the z direction.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslsplitOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLSPLIT_METADATA)
    cargs = []
    cargs.append("fslsplit")
    cargs.append(execution.input_file(infile))
    if output_basename is not None:
        cargs.append(output_basename)
    if separation_z:
        cargs.append("-z")
    ret = FslsplitOutputs(
        root=execution.output_file("."),
        outfiles=execution.output_file(output_basename + "????.nii.gz") if (output_basename is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLSPLIT_METADATA",
    "FslsplitOutputs",
    "fslsplit",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLADD_METADATA = Metadata(
    id="296fc8cd9627bd33d78bcb09e3e55336f873c087.boutiques",
    name="fsladd",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FsladdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsladd(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    resulting_output: OutputPathType
    """Resulting output file"""


def fsladd(
    output_file: InputPathType,
    volume_list: list[InputPathType],
    mean_flag: bool = False,
    scale_flag: bool = False,
    runner: Runner | None = None,
) -> FsladdOutputs:
    """
    Tool for adding or averaging multiple input volumes.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        output_file: Output volume file.
        volume_list: List of input volumes.
        mean_flag: Calculate mean instead of sum.
        scale_flag: Scale each input image mean to 1000 before processing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FsladdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLADD_METADATA)
    cargs = []
    cargs.append("fsladd")
    cargs.append(execution.input_file(output_file))
    if mean_flag:
        cargs.append("-m")
    if scale_flag:
        cargs.append("-s")
    cargs.extend([execution.input_file(f) for f in volume_list])
    ret = FsladdOutputs(
        root=execution.output_file("."),
        resulting_output=execution.output_file(pathlib.Path(output_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLADD_METADATA",
    "FsladdOutputs",
    "fsladd",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WPNG_METADATA = Metadata(
    id="e13f41c54e797426555b18e8ee2168e2d22fafd2.boutiques",
    name="wpng",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class WpngOutputs(typing.NamedTuple):
    """
    Output object returned when calling `wpng(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Converted PNG file"""


def wpng(
    gamma: float | None = None,
    bgcolor: str | None = None,
    text_flag: bool = False,
    time_flag: bool = False,
    interlace_flag: bool = False,
    input_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> WpngOutputs:
    """
    Simple PGM/PPM/PAM to PNG Converter.
    
    Author: Unknown
    
    Args:
        gamma: Transfer-function exponent (``gamma'') of the image in\
            floating-point format (e.g., ``0.45455''). If image looks correct on\
            given display system, image gamma is equal to inverse of display-system\
            exponent, i.e., 1 / (LUT * CRT) (where LUT = lookup-table exponent and\
            CRT = CRT exponent; first varies, second is usually 2.2, all are\
            positive).
        bgcolor: Desired background color for alpha-channel images, in\
            7-character hex RGB format (e.g., ``#ff7700'' for orange: same as HTML\
            colors).
        text_flag: Prompt interactively for text info (tEXt chunks).
        time_flag: Include a tIME chunk (last modification time).
        interlace_flag: Write interlaced PNG image.
        input_file: Input PNM file (binary PGM 'P5', PPM 'P6' or PAM 'P8').
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WpngOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WPNG_METADATA)
    cargs = []
    cargs.append("wpng")
    if gamma is not None:
        cargs.extend([
            "-gamma",
            str(gamma)
        ])
    if bgcolor is not None:
        cargs.extend([
            "-bgcolor",
            bgcolor
        ])
    if text_flag:
        cargs.append("-text")
    if time_flag:
        cargs.append("-time")
    if interlace_flag:
        cargs.append("-interlace")
    if input_file is not None:
        cargs.append(execution.input_file(input_file))
    ret = WpngOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[INPUT_FILE_BASE_NAME].png"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WPNG_METADATA",
    "WpngOutputs",
    "wpng",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_TOOLS_METADATA = Metadata(
    id="8bf4e740f2ac7414b43e404dbbfdd4ff20327bbf.boutiques",
    name="reg_tools",
    package="niftyreg",
    container_image_tag="vnmd/niftyreg_1.4.0:20220819",
)


class RegToolsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_tools(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType | None
    """File containing the output image"""


def reg_tools(
    input_image: InputPathType,
    output_image: str | None = None,
    runner: Runner | None = None,
) -> RegToolsOutputs:
    """
    A versatile tool for manipulating and processing medical images.
    
    Author: Marc Modat
    
    URL: http://cmictig.cs.ucl.ac.uk/wiki/index.php/NiftyReg
    
    Args:
        input_image: Filename of the input image.
        output_image: Filename of the output image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegToolsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_TOOLS_METADATA)
    cargs = []
    cargs.append("reg_tools")
    cargs.extend([
        "-in",
        execution.input_file(input_image)
    ])
    if output_image is not None:
        cargs.extend([
            "-out",
            output_image
        ])
    cargs.append("[OPTIONS]")
    ret = RegToolsOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(output_image) if (output_image is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_TOOLS_METADATA",
    "RegToolsOutputs",
    "reg_tools",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ROBUST_FOV_METADATA = Metadata(
    id="8d3542da3aec86d33d2ee9f3b412262f8f042a11.boutiques",
    name="robust_fov",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class RobustFovOutputs(typing.NamedTuple):
    """
    Output object returned when calling `robust_fov(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_roi: OutputPathType
    """Roi volume output name."""
    out_transform: OutputPathType
    """Transformation matrix in_file to out_roi output name."""
    out_roi_: OutputPathType
    """Roi volume output name."""
    out_transform_: OutputPathType
    """Transformation matrix in_file to out_roi output name."""


def robust_fov(
    in_file: InputPathType,
    brainsize: int | None = None,
    output_type: typing.Literal["NIFTI", "NIFTI_PAIR", "NIFTI_GZ", "NIFTI_PAIR_GZ"] | None = None,
    runner: Runner | None = None,
) -> RobustFovOutputs:
    """
    Automatically crops an image removing lower head and neck.
    Interface is stable 5.0.0 to 5.0.9, but default brainsize changed from 150mm
    to 170mm.
    
    Author: Nipype (interface)
    
    Args:
        in_file: Input filename.
        brainsize: Size of brain in z-dimension (default 170mm/150mm).
        output_type: 'nifti' or 'nifti_pair' or 'nifti_gz' or 'nifti_pair_gz'.\
            Fsl output type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RobustFovOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ROBUST_FOV_METADATA)
    cargs = []
    cargs.append("RobustFOV")
    cargs.extend([
        "-i",
        execution.input_file(in_file)
    ])
    if brainsize is not None:
        cargs.extend([
            "-b",
            str(brainsize)
        ])
    cargs.append("[OUT_ROI]")
    cargs.append("[OUT_TRANSFORM]")
    if output_type is not None:
        cargs.append(output_type)
    ret = RobustFovOutputs(
        root=execution.output_file("."),
        out_roi=execution.output_file(pathlib.Path(in_file).name + "_ROI"),
        out_transform=execution.output_file(pathlib.Path(in_file).name + "_to_ROI"),
        out_roi_=execution.output_file("out_roi"),
        out_transform_=execution.output_file("out_transform"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ROBUST_FOV_METADATA",
    "RobustFovOutputs",
    "robust_fov",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MSS_METADATA = Metadata(
    id="121bc2fa9d402372cae4610a91a167c407c33ae3.boutiques",
    name="3dMSS",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMssOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_mss(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file in NIfTI format"""


def v_3d_mss(
    prefix: str,
    data_table: InputPathType,
    jobs: float | None = None,
    mrr_formula: str | None = None,
    lme_formula: str | None = None,
    random_effect: str | None = None,
    qvars: str | None = None,
    mask: InputPathType | None = None,
    bounds: list[float] | None = None,
    prediction_table: InputPathType | None = None,
    cio_flag: bool = False,
    rio_flag: bool = False,
    help_flag: bool = False,
    dbg_args_flag: bool = False,
    if_name: str | None = None,
    show_allowed_options_flag: bool = False,
    sdiff_vars: str | None = None,
    vt_formula: str | None = None,
    runner: Runner | None = None,
) -> V3dMssOutputs:
    """
    Voxelwise Multilevel Smoothing Spline (MSS) Analysis.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dMSS.html
    
    Args:
        prefix: Output file name. For AFNI format, provide prefix only, with no\
            view+suffix needed. Filename for NIfTI format should have .nii\
            attached.
        data_table: List the data structure with a header as the first line.
        jobs: Number of CPU cores for parallel processing.
        mrr_formula: Model formulation through multilevel smoothing splines.
        lme_formula: Specify the fixed effect components of the model.
        random_effect: Specify the random effect components of the model.
        qvars: Identify quantitative variables (or covariates). The list with\
            more than one variable has to be separated with comma without any other\
            characters.
        mask: Process voxels inside this mask only.
        bounds: Outlier removal bounds. Any values in the input data that are\
            beyond the bounds will be removed and treated as missing.
        prediction_table: Provide a data table so that predicted values could\
            be generated for graphical illustration.
        cio_flag: Use AFNI's C io functions, which is default.
        rio_flag: Use R's io functions.
        help_flag: Display help message.
        dbg_args_flag: Enable R to save the parameters in a file called\
            .3dMSS.dbg.AFNI.args for debugging.
        if_name: Specify the column name that is designated for input files of\
            effect estimate. Default is 'InputFile'.
        show_allowed_options_flag: List of allowed options.
        sdiff_vars: Specify the factors for group comparisons.
        vt_formula: Specify varying smoothing terms. Two components are\
            required: the first one 'var' indicates the variable (e.g., subject)\
            around which the smoothing will vary while the second component\
            specifies the smoothing formulation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMssOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MSS_METADATA)
    cargs = []
    cargs.append("3dMSS")
    cargs.append(prefix)
    if jobs is not None:
        cargs.extend([
            "-jobs",
            str(jobs)
        ])
    if mrr_formula is not None:
        cargs.extend([
            "-mrr",
            mrr_formula
        ])
    if lme_formula is not None:
        cargs.extend([
            "-lme",
            lme_formula
        ])
    if random_effect is not None:
        cargs.extend([
            "-ranEff",
            random_effect
        ])
    if qvars is not None:
        cargs.extend([
            "-qVars",
            qvars
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if bounds is not None:
        cargs.extend([
            "-bounds",
            *map(str, bounds)
        ])
    if prediction_table is not None:
        cargs.extend([
            "-prediction",
            execution.input_file(prediction_table)
        ])
    cargs.extend([
        "-dataTable",
        execution.input_file(data_table)
    ])
    if cio_flag:
        cargs.append("-cio")
    if rio_flag:
        cargs.append("-Rio")
    if help_flag:
        cargs.append("-help")
    if dbg_args_flag:
        cargs.append("-dbgArgs")
    if if_name is not None:
        cargs.extend([
            "-IF",
            if_name
        ])
    if show_allowed_options_flag:
        cargs.append("-show_allowed_options")
    if sdiff_vars is not None:
        cargs.extend([
            "-sdiff",
            sdiff_vars
        ])
    if vt_formula is not None:
        cargs.extend([
            "-vt",
            vt_formula
        ])
    ret = V3dMssOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".nii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMssOutputs",
    "V_3D_MSS_METADATA",
    "v_3d_mss",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DICOM_HDR_METADATA = Metadata(
    id="761c97ea8d89c4844c459d04c4ca44b9f1f1e25e.boutiques",
    name="dicom_hdr",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class DicomHdrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dicom_hdr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dicom_hdr(
    files: list[InputPathType],
    runner: Runner | None = None,
) -> DicomHdrOutputs:
    """
    A tool to print DICOM file information to stdout.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/dicom_hdr.html
    
    Args:
        files: DICOM file(s) to read.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DicomHdrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DICOM_HDR_METADATA)
    cargs = []
    cargs.append("dicom_hdr")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in files])
    ret = DicomHdrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DICOM_HDR_METADATA",
    "DicomHdrOutputs",
    "dicom_hdr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ROIGROW_METADATA = Metadata(
    id="23565f80bef0896060c03352b094c4ed57329a14.boutiques",
    name="ROIgrow",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class RoigrowOutputs(typing.NamedTuple):
    """
    Output object returned when calling `roigrow(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """1D output dataset."""


def roigrow(
    full_list: bool = False,
    grow_from_edge: bool = False,
    insphere_diameter: float | None = None,
    inbox_edges: list[float] | None = None,
    runner: Runner | None = None,
) -> RoigrowOutputs:
    """
    A program to expand an ROI on the surface.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/ROIgrow.html
    
    Args:
        full_list: Output a row for each node on the surface. Nodes not in the\
            grown ROI, receive a 0 for a label. This option is ONLY for use with\
            -roi_labels.
        grow_from_edge: Grow ROIs from their edges rather than the brute force\
            default. This might make the program faster on large ROIs and large\
            surfaces.
        insphere_diameter: Diameter of the sphere inside which nodes are added\
            instead of growing along the surface.
        inbox_edges: Use a box of edge widths E1, E2, E3 instead of DIA.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RoigrowOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ROIGROW_METADATA)
    cargs = []
    cargs.append("ROIgrow")
    cargs.append("<-i_TYPE")
    cargs.append("SURF>")
    cargs.append("<-roi_labels")
    cargs.append("ROI_LABELS>")
    cargs.append("<-lim")
    cargs.append("LIM>")
    cargs.append("[-prefix")
    cargs.append("PREFIX]")
    if full_list:
        cargs.append("-full_list")
    if grow_from_edge:
        cargs.append("-grow_from_edge")
    if insphere_diameter is not None:
        cargs.extend([
            "-insphere",
            str(insphere_diameter)
        ])
    if inbox_edges is not None:
        cargs.extend([
            "-inbox",
            *map(str, inbox_edges)
        ])
    ret = RoigrowOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[PREFIX].1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ROIGROW_METADATA",
    "RoigrowOutputs",
    "roigrow",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SUMA_ALIGN_TO_EXPERIMENT_METADATA = Metadata(
    id="f2f26937329becfebaa8846f69efba5bc54af24c.boutiques",
    name="@SUMA_AlignToExperiment",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSumaAlignToExperimentOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__suma_align_to_experiment(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    aligned_volume: OutputPathType
    """Output volume after alignment."""
    additional_followers: OutputPathType
    """Output followers dataset after transforming."""


def v__suma_align_to_experiment(
    runner: Runner | None = None,
) -> VSumaAlignToExperimentOutputs:
    """
    Creates a version of Surface Anatomy that is registered to Experiment Anatomy.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@SUMA_AlignToExperiment.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSumaAlignToExperimentOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SUMA_ALIGN_TO_EXPERIMENT_METADATA)
    cargs = []
    cargs.append("@SUMA_AlignToExperiment")
    cargs.append("<-exp_anat")
    cargs.append("$$exp_anat$$>")
    cargs.append("<-surf_anat")
    cargs.append("$$surf_anat$$>")
    cargs.append("$$dxyz$$")
    cargs.append("$$wd$$")
    cargs.append("$$prefix$$")
    cargs.append("$$EA_clip_below$$")
    cargs.append("$$align_centers$$")
    cargs.append("$$ok_change_view$$")
    cargs.append("$$strip_skull$$")
    ret = VSumaAlignToExperimentOutputs(
        root=execution.output_file("."),
        aligned_volume=execution.output_file("[PREFIX]_Alnd_Exp.nii.gz"),
        additional_followers=execution.output_file("[PREFIX]_Alnd_Exp_Fdset.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSumaAlignToExperimentOutputs",
    "V__SUMA_ALIGN_TO_EXPERIMENT_METADATA",
    "v__suma_align_to_experiment",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRSTATS_METADATA = Metadata(
    id="d6b6130eadba4cd34c792009b27a777f19edbda6.boutiques",
    name="mrstats",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MrstatsOutput:
    """
    output only the field specified. Multiple such options can be supplied if
    required. Choices are: mean, median, std, std_rv, min, max, count. Useful
    for use in scripts. Both std options refer to the unbiased (sample) standard
    deviation. For complex data, min, max and std are calculated separately for
    real and imaginary parts, std_rv is based on the real valued variance
    (equals sqrt of sum of variances of imaginary and real parts).
    """
    field: str
    """output only the field specified. Multiple such options can be supplied if
    required. Choices are: mean, median, std, std_rv, min, max, count. Useful
    for use in scripts. Both std options refer to the unbiased (sample) standard
    deviation. For complex data, min, max and std are calculated separately for
    real and imaginary parts, std_rv is based on the real valued variance
    (equals sqrt of sum of variances of imaginary and real parts)."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-output")
        cargs.append(self.field)
        return cargs


@dataclasses.dataclass
class MrstatsConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class MrstatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrstats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mrstats(
    image: InputPathType,
    output: list[MrstatsOutput] | None = None,
    mask: InputPathType | None = None,
    ignorezero: bool = False,
    allvolumes: bool = False,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MrstatsConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrstatsOutputs:
    """
    Compute images statistics.
    
    
    
    References:
    
    .
    
    Author: J-Donald Tournier (jdtournier@gmail.com)
    
    URL: https://mrtrix.readthedocs.io/en/latest/reference/commands/mrstats.html
    
    Args:
        image: the input image from which statistics will be computed.
        output: output only the field specified. Multiple such options can be\
            supplied if required. Choices are: mean, median, std, std_rv, min, max,\
            count. Useful for use in scripts. Both std options refer to the\
            unbiased (sample) standard deviation. For complex data, min, max and\
            std are calculated separately for real and imaginary parts, std_rv is\
            based on the real valued variance (equals sqrt of sum of variances of\
            imaginary and real parts).
        mask: only perform computation within the specified binary mask image.
        ignorezero: ignore zero values during statistics calculation.
        allvolumes: generate statistics across all image volumes, rather than\
            one set of statistics per image volume.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrstatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRSTATS_METADATA)
    cargs = []
    cargs.append("mrstats")
    if output is not None:
        cargs.extend([a for c in [s.run(execution) for s in output] for a in c])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if ignorezero:
        cargs.append("-ignorezero")
    if allvolumes:
        cargs.append("-allvolumes")
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(image))
    ret = MrstatsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRSTATS_METADATA",
    "MrstatsConfig",
    "MrstatsOutput",
    "MrstatsOutputs",
    "mrstats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DTEIG_METADATA = Metadata(
    id="9bdc110c1aa425f5867b362872318f6ae6a347db.boutiques",
    name="3dDTeig",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDteigOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_dteig(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Output dataset with computed eigenvalues, eigenvectors, FA, and MD"""
    output_lambda: OutputPathType
    """Output dataset for eigenvalues"""
    output_eigvec: OutputPathType
    """Output dataset for eigenvectors"""
    output_fa: OutputPathType
    """Output dataset for fractional anisotropy"""
    output_md: OutputPathType
    """Output dataset for mean diffusivity"""


def v_3d_dteig(
    input_dataset: str,
    runner: Runner | None = None,
) -> V3dDteigOutputs:
    """
    Computes eigenvalues and eigenvectors for an input dataset of tensors.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dDTeig.html
    
    Args:
        input_dataset: Input dataset of Dxx, Dxy, Dyy, Dxz, Dyz, Dzz sub-bricks.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDteigOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DTEIG_METADATA)
    cargs = []
    cargs.append("3dDTeig")
    cargs.append("[OPTIONS]")
    cargs.append(input_dataset)
    ret = V3dDteigOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file("[PREFIX].nii.gz"),
        output_lambda=execution.output_file("[PREFIX]_lambda.nii.gz"),
        output_eigvec=execution.output_file("[PREFIX]_eigvec.nii.gz"),
        output_fa=execution.output_file("[PREFIX]_FA.nii.gz"),
        output_md=execution.output_file("[PREFIX]_MD.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDteigOutputs",
    "V_3D_DTEIG_METADATA",
    "v_3d_dteig",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_SLICE_NDICE_METADATA = Metadata(
    id="8ccf047f16d1ba8b1a3d47de84307e15981d5c06.boutiques",
    name="3dSliceNDice",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dSliceNdiceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_slice_ndice(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_rl: OutputPathType
    """Output file containing Dice coefficients along the right-left axis."""
    output_ap: OutputPathType
    """Output file containing Dice coefficients along the anterior-posterior
    axis."""
    output_is: OutputPathType
    """Output file containing Dice coefficients along the inferior-superior
    axis."""


def v_3d_slice_ndice(
    infile_a: InputPathType,
    infile_b: InputPathType,
    output_prefix: str,
    out_domain: typing.Literal["all", "AorB", "AandB", "Amask", "Bmask"] | None = None,
    no_cmd_echo: bool = False,
    runner: Runner | None = None,
) -> V3dSliceNdiceOutputs:
    """
    Calculates the Dice coefficient between two volumes on a slice-by-slice basis.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dSliceNDice.html
    
    Args:
        infile_a: Input dataset A (e.g. mask_1.nii.gz).
        infile_b: Input dataset B (e.g. mask_2.nii.gz).
        output_prefix: Prefix for output files (e.g. result_prefix).
        out_domain: Specify which slices to include in the Dice coefficient\
            report. Options are: all (default), AorB, AandB, Amask, Bmask.
        no_cmd_echo: Turn OFF recording the command line call in the output\
            *.1D files. Default is to do the recording.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dSliceNdiceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_SLICE_NDICE_METADATA)
    cargs = []
    cargs.append("3dSliceNDice")
    cargs.append("-insetA")
    cargs.append(execution.input_file(infile_a))
    cargs.append("-insetB")
    cargs.append(execution.input_file(infile_b))
    cargs.append("-prefix")
    cargs.append(output_prefix)
    if out_domain is not None:
        cargs.extend([
            "-out_domain",
            out_domain
        ])
    if no_cmd_echo:
        cargs.append("-no_cmd_echo")
    ret = V3dSliceNdiceOutputs(
        root=execution.output_file("."),
        output_rl=execution.output_file(output_prefix + "_0_RL.1D"),
        output_ap=execution.output_file(output_prefix + "_1_AP.1D"),
        output_is=execution.output_file(output_prefix + "_2_IS.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dSliceNdiceOutputs",
    "V_3D_SLICE_NDICE_METADATA",
    "v_3d_slice_ndice",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QHULL_METADATA = Metadata(
    id="668aff173881084f61d492e13c45a93cb6ecbcb7.boutiques",
    name="qhull",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class QhullOutputs(typing.NamedTuple):
    """
    Output object returned when calling `qhull(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_results: OutputPathType
    """Output file with the specified results."""


def qhull(
    runner: Runner | None = None,
) -> QhullOutputs:
    """
    Tool to compute convex hulls and related structures.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/qhull.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QhullOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QHULL_METADATA)
    cargs = []
    cargs.append("qhull")
    cargs.append("[OPTIONS]")
    cargs.append("[OUTPUT_OPTIONS]")
    ret = QhullOutputs(
        root=execution.output_file("."),
        output_results=execution.output_file("[OUTPUT_FILE].txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QHULL_METADATA",
    "QhullOutputs",
    "qhull",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DEGREE_CENTRALITY_METADATA = Metadata(
    id="22f490673264fd97dadfc685c6bb6b55f1751d3c.boutiques",
    name="3dDegreeCentrality",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDegreeCentralityOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_degree_centrality(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output image file name."""
    oned_file_outfile: OutputPathType | None
    """The text output of the similarity matrix computed after thresholding with
    one-dimensional and ijk voxel indices, correlations, image extents, and
    affine matrix."""


def v_3d_degree_centrality(
    in_file: InputPathType,
    autoclip: bool = False,
    automask: bool = False,
    mask: InputPathType | None = None,
    oned_file: str | None = None,
    polort: int | None = None,
    sparsity: float | None = None,
    thresh: float | None = None,
    runner: Runner | None = None,
) -> V3dDegreeCentralityOutputs:
    """
    Computes voxelwise weighted and binary degree centrality and stores the result
    in a new 3D bucket dataset as floats to preserve their values. Degree centrality
    reflects the strength and extent of the correlation of a voxel with every other
    voxel in the brain. .
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dDegreeCentrality.html
    
    Args:
        in_file: Input file to 3ddegreecentrality.
        autoclip: Clip off low-intensity regions in the dataset.
        automask: Mask the dataset to target brain-only voxels.
        mask: Mask file to mask input data.
        oned_file: Output filepath to text dump of correlation matrix.
        polort: No description provided.
        sparsity: Only take the top percent of connections.
        thresh: Threshold to exclude connections where corr <= thresh.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDegreeCentralityOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DEGREE_CENTRALITY_METADATA)
    cargs = []
    cargs.append("3dDegreeCentrality")
    cargs.append(execution.input_file(in_file))
    if autoclip:
        cargs.append("-autoclip")
    if automask:
        cargs.append("-automask")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if oned_file is not None:
        cargs.extend([
            "-out1D",
            oned_file
        ])
    cargs.append("[OUT_FILE]")
    if polort is not None:
        cargs.extend([
            "-polort",
            str(polort)
        ])
    if sparsity is not None:
        cargs.extend([
            "-sparsity",
            str(sparsity)
        ])
    if thresh is not None:
        cargs.extend([
            "-thresh",
            str(thresh)
        ])
    ret = V3dDegreeCentralityOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file).name),
        oned_file_outfile=execution.output_file(oned_file) if (oned_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDegreeCentralityOutputs",
    "V_3D_DEGREE_CENTRALITY_METADATA",
    "v_3d_degree_centrality",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PNM_EVS_METADATA = Metadata(
    id="415a4b0e63f6c87fa510da1a15528fc5136f88c7.boutiques",
    name="pnm_evs",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PnmEvsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `pnm_evs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output confound/EV matrix file"""


def pnm_evs(
    input_file: InputPathType,
    output_file: str,
    tr_value: float,
    cardiac_file: InputPathType | None = None,
    respiratory_file: InputPathType | None = None,
    order_cardiac: float | None = 2,
    order_respiratory: float | None = 1,
    order_mult_cardiac: float | None = 0,
    order_mult_respiratory: float | None = 0,
    csf_mask: InputPathType | None = None,
    rvt_file: InputPathType | None = None,
    heartrate_file: InputPathType | None = None,
    rvt_smooth: float | None = 0,
    heartrate_smooth: float | None = None,
    slice_direction: str | None = "z",
    slice_order: str | None = None,
    slice_timing_file: InputPathType | None = None,
    debug_flag: bool = False,
    verbose_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> PnmEvsOutputs:
    """
    PNM EVs: Generates physiological noise regressors for fMRI data.
    
    Author: University of Oxford (Mark Jenkinson)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/PNM
    
    Args:
        input_file: Input image filename (4D functional/EPI data).
        output_file: Output filename (for confound/EV matrix).
        tr_value: TR of fMRI volumes (in seconds).
        cardiac_file: Input filename for cardiac values (1 or 2 columns: time\
            [phase]).
        respiratory_file: Input filename for respiratory phase values (1 or 2\
            columns: time [phase]).
        order_cardiac: Order of basic cardiac regressors (number of Fourier\
            pairs).
        order_respiratory: Order of basic respiratory regressors (number of\
            Fourier pairs).
        order_mult_cardiac: Order of multiplicative cardiac terms (also need to\
            set --multr).
        order_mult_respiratory: Order of multiplicative respiratory terms (also\
            need to set --multc).
        csf_mask: Filename of CSF mask image (and generate CSF regressor).
        rvt_file: Input filename of RVT data (2 columns: time value).
        heartrate_file: Input filename for heart rate data (2 columns: time\
            value).
        rvt_smooth: Optional smoothing of RVT regressor (in seconds).
        heartrate_smooth: Optional smoothing of heart rate regressor (in\
            seconds).
        slice_direction: Specify slice direction (x/y/z).
        slice_order: Specify slice ordering\
            (up/down/interleaved_up/interleaved_down).
        slice_timing_file: Specify slice timing via an external file.
        debug_flag: Turn on debugging output.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PnmEvsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PNM_EVS_METADATA)
    cargs = []
    cargs.append("pnm_evs")
    cargs.extend([
        "--in",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "--out",
        output_file
    ])
    cargs.extend([
        "--tr",
        str(tr_value)
    ])
    if cardiac_file is not None:
        cargs.extend([
            "--cardiac",
            execution.input_file(cardiac_file)
        ])
    if respiratory_file is not None:
        cargs.extend([
            "--respiratory",
            execution.input_file(respiratory_file)
        ])
    if order_cardiac is not None:
        cargs.extend([
            "--oc",
            str(order_cardiac)
        ])
    if order_respiratory is not None:
        cargs.extend([
            "--or",
            str(order_respiratory)
        ])
    if order_mult_cardiac is not None:
        cargs.extend([
            "--multc",
            str(order_mult_cardiac)
        ])
    if order_mult_respiratory is not None:
        cargs.extend([
            "--multr",
            str(order_mult_respiratory)
        ])
    if csf_mask is not None:
        cargs.extend([
            "--csfmask",
            execution.input_file(csf_mask)
        ])
    if rvt_file is not None:
        cargs.extend([
            "--rvt",
            execution.input_file(rvt_file)
        ])
    if heartrate_file is not None:
        cargs.extend([
            "--heartrate",
            execution.input_file(heartrate_file)
        ])
    if rvt_smooth is not None:
        cargs.extend([
            "--rvtsmooth",
            str(rvt_smooth)
        ])
    if heartrate_smooth is not None:
        cargs.extend([
            "--heartratesmooth",
            str(heartrate_smooth)
        ])
    if slice_direction is not None:
        cargs.extend([
            "--slicedir",
            slice_direction
        ])
    if slice_order is not None:
        cargs.extend([
            "--sliceorder",
            slice_order
        ])
    if slice_timing_file is not None:
        cargs.extend([
            "--slicetiming",
            execution.input_file(slice_timing_file)
        ])
    if debug_flag:
        cargs.append("--debug")
    if verbose_flag:
        cargs.append("--verbose")
    if help_flag:
        cargs.append("--help")
    ret = PnmEvsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PNM_EVS_METADATA",
    "PnmEvsOutputs",
    "pnm_evs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BRAIN_EXTRACTION_SH_METADATA = Metadata(
    id="71f5f53f1bd6af174207b63fb6c2714bd1844de7.boutiques",
    name="brain_extraction_sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class BrainExtractionShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `brain_extraction_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    brain_extracted_image: OutputPathType | None
    """Brain extracted image"""
    brain_mask: OutputPathType | None
    """Brain mask"""
    brain_probability_mask: OutputPathType | None
    """Brain probability mask"""


def brain_extraction_sh(
    anatomical_image: InputPathType,
    template: InputPathType,
    probability_mask: InputPathType,
    image_dimension: int = 3,
    tissue_classification: str | None = None,
    brain_extraction_registration_mask: InputPathType | None = None,
    keep_temporary_files: bool = False,
    single_floating_point_precision: bool = False,
    initial_moving_transform: InputPathType | None = None,
    rotation_search_params: str | None = None,
    image_file_suffix: str | None = None,
    translation_search_params: str | None = None,
    random_seeding: bool = False,
    debug_mode: bool = False,
    output_prefix: str | None = "output",
    runner: Runner | None = None,
) -> BrainExtractionShOutputs:
    """
    antsBrainExtraction.sh is a script from Advanced Normalization Tools (ANTs) for
    template-based brain extraction.
    
    Author: Advanced Normalization Tools (ANTs) Contributors
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        anatomical_image: Anatomical image (Structural image, typically T1).
        template: Brain extraction template (Anatomical template).
        probability_mask: Brain extraction probability mask.
        image_dimension: Image dimension (2 or 3).
        tissue_classification: Tissue classification.
        brain_extraction_registration_mask: Brain extraction registration mask.
        keep_temporary_files: Keep temporary files.
        single_floating_point_precision: Use single floating point precision.
        initial_moving_transform: Initial moving transform.
        rotation_search_params: Rotation search parameters.
        image_file_suffix: Image file suffix.
        translation_search_params: Translation search parameters.
        random_seeding: Use random seeding.
        debug_mode: Test / debug mode.
        output_prefix: Output prefix.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BrainExtractionShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BRAIN_EXTRACTION_SH_METADATA)
    cargs = []
    cargs.append("antsBrainExtraction.sh")
    cargs.append("-d")
    cargs.append(str(image_dimension))
    cargs.append("-a")
    cargs.append(execution.input_file(anatomical_image))
    cargs.append("-e")
    cargs.append(execution.input_file(template))
    cargs.append("-m")
    cargs.append(execution.input_file(probability_mask))
    if tissue_classification is not None:
        cargs.extend([
            "-c",
            tissue_classification
        ])
    if brain_extraction_registration_mask is not None:
        cargs.extend([
            "-f",
            execution.input_file(brain_extraction_registration_mask)
        ])
    if keep_temporary_files:
        cargs.append("-k")
    if single_floating_point_precision:
        cargs.append("-q")
    if initial_moving_transform is not None:
        cargs.extend([
            "-r",
            execution.input_file(initial_moving_transform)
        ])
    if rotation_search_params is not None:
        cargs.extend([
            "-R",
            rotation_search_params
        ])
    if image_file_suffix is not None:
        cargs.extend([
            "-s",
            image_file_suffix
        ])
    if translation_search_params is not None:
        cargs.extend([
            "-T",
            translation_search_params
        ])
    if random_seeding:
        cargs.append("-u")
    if debug_mode:
        cargs.append("-z")
    cargs.append("-o")
    if output_prefix is not None:
        cargs.append(output_prefix)
    ret = BrainExtractionShOutputs(
        root=execution.output_file("."),
        brain_extracted_image=execution.output_file(output_prefix + "BrainExtractionBrain.nii.gz") if (output_prefix is not None) else None,
        brain_mask=execution.output_file(output_prefix + "BrainExtractionMask.nii.gz") if (output_prefix is not None) else None,
        brain_probability_mask=execution.output_file(output_prefix + "BrainExtractionPrior0GenericAffine.mat") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BRAIN_EXTRACTION_SH_METADATA",
    "BrainExtractionShOutputs",
    "brain_extraction_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_SELECT_STR_PY_METADATA = Metadata(
    id="edf90a625a50ba02dc94acf4f7ed5a86797fc178.boutiques",
    name="adjunct_select_str.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctSelectStrPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_select_str_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def adjunct_select_str_py(
    input_file: InputPathType,
    num_bricks: float,
    output_file: str,
    runner: Runner | None = None,
) -> AdjunctSelectStrPyOutputs:
    """
    A simple helper function for the fat_proc* scripts.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/adjunct_select_str.py.html
    
    Args:
        input_file: File containing a list of integers.
        num_bricks: The number N of bricks in the dataset (so max index is N-1).
        output_file: Output file name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctSelectStrPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_SELECT_STR_PY_METADATA)
    cargs = []
    cargs.append("/opt/afni/src/../install/adjunct_select_str.py")
    cargs.append(execution.input_file(input_file))
    cargs.append(str(num_bricks))
    cargs.append(output_file)
    ret = AdjunctSelectStrPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_SELECT_STR_PY_METADATA",
    "AdjunctSelectStrPyOutputs",
    "adjunct_select_str_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_PFM_METADATA = Metadata(
    id="aa3a0f796c8daf75c7dc58292088177e76e9fa4f.boutiques",
    name="3dPFM",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dPfmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_pfm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    beta: OutputPathType
    """Prefix for the neuronal-related (i.e. deconvolved) time series."""
    betafitts: OutputPathType
    """Prefix of the convolved neuronal-related time series."""
    fitts: OutputPathType
    """Prefix for the fitted time series."""
    resid: OutputPathType
    """Prefix for the residuals of the fit to the data."""
    mean: OutputPathType
    """Prefix for the intercept of the model."""
    lhsest: OutputPathType
    """Prefix for the estimates of the LHS parameters."""
    lhsfitts: OutputPathType
    """Prefix for the fitted time series of the LHS parameters."""
    lambda_: OutputPathType
    """Prefix for output volume with the regularization parameter of the
    deconvolution of each voxel."""
    costs: OutputPathType
    """Prefix for output volume of the cost function used to select the
    regularization parameter according to the selected criteria."""
    tstats_beta: OutputPathType
    """Prefix for the T-statistics of beta at each time point."""
    tdf_beta: OutputPathType
    """Prefix for degrees of freedom of the T-statistics of beta."""
    z_tstats_beta: OutputPathType
    """Prefix for (normalized) z-scores of the T-statistics of beta."""
    fstats_beta: OutputPathType
    """Prefix for the F-statistics of the deconvolved component."""
    fdf_beta: OutputPathType
    """Prefix for degrees of freedom of Fstats_beta."""
    z_fstats_beta: OutputPathType
    """Prefix for (normalized) z-scores of the Fstats_beta."""
    tstats_lhs: OutputPathType
    """Prefix for T-statistics of LHS regressors at each time point."""
    tdf_lhs: OutputPathType
    """Prefix for degrees of freedom of the Tstats_LHS."""
    z_tstats_lhs: OutputPathType
    """Prefix for (normalized) z-scores of the Tstats_LHS."""
    fstats_lhs: OutputPathType
    """Prefix for the F-statistics of the LHS regressors."""
    fdf_lhs: OutputPathType
    """Prefix for degrees of freedom of Fstats_LHS."""
    z_fstats_lhs: OutputPathType
    """Prefix for (normalized) z-scores of Fstats_LHS."""
    fstats_full: OutputPathType
    """Prefix for the F-statistics of the full model."""
    fdf_full: OutputPathType
    """Prefix for degrees of freedom of Fstats_full."""
    z_fstats_full: OutputPathType
    """Prefix for (normalized) z-scores of Fstats_full."""
    r2_full: OutputPathType
    """Prefix for R² (coefficient of determination) of the full model."""
    r2adj_full: OutputPathType
    """Prefix for Adjusted R² coefficient for the full model."""


def v_3d_pfm(
    runner: Runner | None = None,
) -> V3dPfmOutputs:
    """
    Program for identifying brief BOLD events in fMRI time series using Paradigm
    Free Mapping.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dPFM.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dPfmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_PFM_METADATA)
    cargs = []
    cargs.append("3dPFM")
    cargs.append("[PARAMETERS]")
    ret = V3dPfmOutputs(
        root=execution.output_file("."),
        beta=execution.output_file("[BETA]"),
        betafitts=execution.output_file("[BETAFITTS]"),
        fitts=execution.output_file("[FITTS]"),
        resid=execution.output_file("[RESID]"),
        mean=execution.output_file("[MEAN]"),
        lhsest=execution.output_file("[LHSEST]"),
        lhsfitts=execution.output_file("[LHSFITTS]"),
        lambda_=execution.output_file("[LAMBDA]"),
        costs=execution.output_file("[COSTS]"),
        tstats_beta=execution.output_file("[TSTATS_BETA]"),
        tdf_beta=execution.output_file("[TDF_BETA]"),
        z_tstats_beta=execution.output_file("[Z_TSTATS_BETA]"),
        fstats_beta=execution.output_file("[FSTATS_BETA]"),
        fdf_beta=execution.output_file("[FDF_BETA]"),
        z_fstats_beta=execution.output_file("[Z_FSTATS_BETA]"),
        tstats_lhs=execution.output_file("[TSTATS_LHS]"),
        tdf_lhs=execution.output_file("[TDF_LHS]"),
        z_tstats_lhs=execution.output_file("[Z_TSTATS_LHS]"),
        fstats_lhs=execution.output_file("[FSTATS_LHS]"),
        fdf_lhs=execution.output_file("[FDF_LHS]"),
        z_fstats_lhs=execution.output_file("[Z_FSTATS_LHS]"),
        fstats_full=execution.output_file("[FSTATS_FULL]"),
        fdf_full=execution.output_file("[FDF_FULL]"),
        z_fstats_full=execution.output_file("[Z_FSTATS_FULL]"),
        r2_full=execution.output_file("[R2_FULL]"),
        r2adj_full=execution.output_file("[R2ADJ_FULL]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dPfmOutputs",
    "V_3D_PFM_METADATA",
    "v_3d_pfm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TRACK_ID_METADATA = Metadata(
    id="c068f5e1d98a8b27b5e0160adf46079d9d5304f8.boutiques",
    name="3dTrackID",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTrackIdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_track_id(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    indimap: OutputPathType
    """Output of INDIMAP"""
    pairmap: OutputPathType
    """Output of PAIRMAP"""
    grid: OutputPathType
    """Text file output of statistics of WM-ROIs"""
    niml_tract: OutputPathType
    """Track-like output for viewing in SUMA"""
    niml_dset: OutputPathType
    """Dataset output for use with *.niml.tract"""
    trk: OutputPathType
    """TrackVis-like output for viewing in TrackVis"""
    pairmap_labeltable: OutputPathType
    """Output of PAIRMAP labeltable"""
    roi_labels: OutputPathType
    """Output file of all ROI labels"""
    option_values: OutputPathType
    """Output of all option values"""


def v_3d_track_id(
    runner: Runner | None = None,
) -> V3dTrackIdOutputs:
    """
    FACTID-based tractography code for AFNI, part of FATCAT.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTrackID.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTrackIdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TRACK_ID_METADATA)
    cargs = []
    cargs.append("3dTrackID")
    cargs.append("-mode")
    cargs.append("{DET")
    cargs.append("|")
    cargs.append("MINIP")
    cargs.append("|")
    cargs.append("PROB}")
    cargs.append("[ALL_REQUIRED_OPTIONS]")
    cargs.append("[MODEL_SPECIFIC_OPTIONS]")
    cargs.append("[MODE_SPECIFIC_OPTIONS]")
    cargs.append("[OTHER_OPTIONS]")
    ret = V3dTrackIdOutputs(
        root=execution.output_file("."),
        indimap=execution.output_file("[PREFIX]_INDIMAP.nii.gz"),
        pairmap=execution.output_file("[PREFIX]_PAIRMAP.nii.gz"),
        grid=execution.output_file("[PREFIX].grid"),
        niml_tract=execution.output_file("[PREFIX].niml.tract"),
        niml_dset=execution.output_file("[PREFIX].niml.dset"),
        trk=execution.output_file("[PREFIX].trk"),
        pairmap_labeltable=execution.output_file("[PREFIX]_PAIRS.niml.lt"),
        roi_labels=execution.output_file("[PREFIX]_roi.labs"),
        option_values=execution.output_file("[PREFIX].niml.opts"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTrackIdOutputs",
    "V_3D_TRACK_ID_METADATA",
    "v_3d_track_id",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DHISTOG_METADATA = Metadata(
    id="1b2daac11db382663e5c96c96beea0ba0cf2559b.boutiques",
    name="3dhistog",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dhistogOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dhistog(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    histogram_output: OutputPathType
    """Histogram output when -prefix option is used"""


def v_3dhistog(
    dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dhistogOutputs:
    """
    Compute histogram of a 3D dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dhistog.html
    
    Args:
        dataset: Input dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dhistogOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DHISTOG_METADATA)
    cargs = []
    cargs.append("3dhistog")
    cargs.append("[EDITING_OPTIONS]")
    cargs.append("[HISTOGRAM_OPTIONS]")
    cargs.append(execution.input_file(dataset))
    ret = V3dhistogOutputs(
        root=execution.output_file("."),
        histogram_output=execution.output_file("HOUT.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dhistogOutputs",
    "V_3DHISTOG_METADATA",
    "v_3dhistog",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PLUGOUT_DRIVE_METADATA = Metadata(
    id="22300b13070d9730d869d6a2398b779c0bc9a168.boutiques",
    name="plugout_drive",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class PlugoutDriveOutputs(typing.NamedTuple):
    """
    Output object returned when calling `plugout_drive(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def plugout_drive(
    host: str | None = None,
    verbose: bool = False,
    port: float | None = None,
    maxwait: float | None = None,
    name: str | None = None,
    command: list[str] | None = None,
    quit_: bool = False,
    runner: Runner | None = None,
) -> PlugoutDriveOutputs:
    """
    This program connects to AFNI and sends commands that the user specifies
    interactively or on command line over to AFNI to be executed.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/plugout_drive.html
    
    Args:
        host: Connect to AFNI running on the specified host using TCP/IP.\
            Default is 'localhost'.
        verbose: Verbose mode.
        port: Use TCP/IP port number. Default is 8099.
        maxwait: Maximum wait time in seconds for AFNI to connect. Default is 9\
            seconds.
        name: Name that AFNI assigns to this plugout. Default is a pre-defined\
            name.
        command: Command to be executed on AFNI. Example: '-com "SET_FUNCTION\
            SomeFunction"'.
        quit_: Quit after executing all -com commands. Default is to wait for\
            more commands.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PlugoutDriveOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PLUGOUT_DRIVE_METADATA)
    cargs = []
    cargs.append("plugout_drive")
    if host is not None:
        cargs.extend([
            "-host",
            host
        ])
    if verbose:
        cargs.append("-v")
    if port is not None:
        cargs.extend([
            "-port",
            str(port)
        ])
    if maxwait is not None:
        cargs.extend([
            "-maxwait",
            str(maxwait)
        ])
    if name is not None:
        cargs.extend([
            "-name",
            name
        ])
    if command is not None:
        cargs.extend([
            "-com",
            *command
        ])
    if quit_:
        cargs.append("-quit")
    ret = PlugoutDriveOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PLUGOUT_DRIVE_METADATA",
    "PlugoutDriveOutputs",
    "plugout_drive",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1DCAT_METADATA = Metadata(
    id="5e596db6798d3b0d404e1685c84fe374efa6a71b.boutiques",
    name="1dcat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dcatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1dcat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    concatenated_output: OutputPathType
    """Concatenated output in specified format"""


def v_1dcat(
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> V1dcatOutputs:
    """
    Concatenates columns of multiple 1D or TSV/CSV files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dcat.html
    
    Args:
        input_files: Input 1D or TSV/CSV files to concatenate.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dcatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1DCAT_METADATA)
    cargs = []
    cargs.append("1dcat")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = V1dcatOutputs(
        root=execution.output_file("."),
        concatenated_output=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dcatOutputs",
    "V_1DCAT_METADATA",
    "v_1dcat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__PARSE_NAME_METADATA = Metadata(
    id="dc595da5a1d86ec673a1a5f7595c19d7c38fd4ad.boutiques",
    name="@parse_name",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VParseNameOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__parse_name(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_path: OutputPathType
    """The path of the filename"""
    output_prefix: OutputPathType
    """The prefix of the filename"""
    output_extension: OutputPathType
    """The extension of the filename"""


def v__parse_name(
    name: str,
    runner: Runner | None = None,
) -> VParseNameOutputs:
    """
    A script to parse a filename into path, prefix, and extension strings.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@parse_name.html
    
    Args:
        name: The filename to parse.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VParseNameOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__PARSE_NAME_METADATA)
    cargs = []
    cargs.append("@parse_name")
    cargs.append(name)
    ret = VParseNameOutputs(
        root=execution.output_file("."),
        output_path=execution.output_file(name + "_path"),
        output_prefix=execution.output_file(name + "_prefix"),
        output_extension=execution.output_file(name + "_extension"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VParseNameOutputs",
    "V__PARSE_NAME_METADATA",
    "v__parse_name",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NIFTI_TOOL_METADATA = Metadata(
    id="d9f2616434f053b6e238d0eace87c16ce9d36fe0.boutiques",
    name="nifti_tool",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class NiftiToolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `nifti_tool(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The nifti file generated as output."""


def nifti_tool(
    action: str,
    input_files: list[InputPathType] | None = None,
    runner: Runner | None = None,
) -> NiftiToolOutputs:
    """
    Display, modify, or compare nifti headers.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/nifti_tool.html
    
    Args:
        action: Action type that defines what nifti_tool will do.
        input_files: One or more input nifti files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NiftiToolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NIFTI_TOOL_METADATA)
    cargs = []
    cargs.append("nifti_tool")
    cargs.append(action)
    if input_files is not None:
        cargs.extend([
            "-infiles",
            *[execution.input_file(f) for f in input_files]
        ])
    cargs.append("[OPTIONS]")
    ret = NiftiToolOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("[PREFIX].nii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NIFTI_TOOL_METADATA",
    "NiftiToolOutputs",
    "nifti_tool",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FLAMEO_METADATA = Metadata(
    id="9745eb3554f097df3abe6c51ae3c2812def42029.boutiques",
    name="flameo",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FlameoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `flameo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dummy_output: OutputPathType


def flameo(
    runner: Runner | None = None,
) -> FlameoOutputs:
    """
    Automatic nipype2boutiques conversion failed.
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FlameoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FLAMEO_METADATA)
    cargs = []
    cargs.append("dummy")
    ret = FlameoOutputs(
        root=execution.output_file("."),
        dummy_output=execution.output_file("dummy_output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FLAMEO_METADATA",
    "FlameoOutputs",
    "flameo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DTISTUDIO_FIBERTO_SEGMENTS_METADATA = Metadata(
    id="3af004da7dceeafdf7d648e011b0d4788bfd2bd3.boutiques",
    name="DTIStudioFibertoSegments",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class DtistudioFibertoSegmentsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dtistudio_fiberto_segments(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_segment_file: OutputPathType | None
    """Output SUMA segment file"""


def dtistudio_fiberto_segments(
    dataset: InputPathType,
    output_file: str | None = None,
    swap_flag: bool = False,
    runner: Runner | None = None,
) -> DtistudioFibertoSegmentsOutputs:
    """
    Convert a DTIStudio Fiber file to a SUMA segment file.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/DTIStudioFibertoSegments.html
    
    Args:
        dataset: Input dataset file.
        output_file: Name of the output file (default is rawxyzseg.dat).
        swap_flag: Swap bytes in data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DtistudioFibertoSegmentsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DTISTUDIO_FIBERTO_SEGMENTS_METADATA)
    cargs = []
    cargs.append("DTIStudioFibertoSegments")
    cargs.append(execution.input_file(dataset))
    if output_file is not None:
        cargs.extend([
            "-output",
            output_file
        ])
    if swap_flag:
        cargs.append("-swap")
    ret = DtistudioFibertoSegmentsOutputs(
        root=execution.output_file("."),
        output_segment_file=execution.output_file(output_file) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DTISTUDIO_FIBERTO_SEGMENTS_METADATA",
    "DtistudioFibertoSegmentsOutputs",
    "dtistudio_fiberto_segments",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_2PERM_METADATA = Metadata(
    id="1f3ac057af6953120bc3c77e4df34915e0c80018.boutiques",
    name="2perm",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V2permOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_2perm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    file_a: OutputPathType | None
    """First subset output file"""
    file_b: OutputPathType | None
    """Second subset output file"""


def v_2perm(
    bottom_int: float,
    top_int: float,
    prefix: str | None = None,
    comma: bool = False,
    subset1_size: float | None = None,
    subset2_size: float | None = None,
    runner: Runner | None = None,
) -> V2permOutputs:
    """
    Generates two random non-overlapping subsets of a given set of integers.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/2perm.html
    
    Args:
        bottom_int: Bottom integer of the range.
        top_int: Top integer of the range.
        prefix: Prefix for output files (default 'AFNIroolz').
        comma: Write each file as a single row of comma-separated numbers.
        subset1_size: Size of the first subset (optional, default is half the\
            range).
        subset2_size: Size of the second subset (optional, default is half the\
            range).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V2permOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_2PERM_METADATA)
    cargs = []
    cargs.append("2perm")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if comma:
        cargs.append("-comma")
    cargs.append(str(bottom_int))
    cargs.append(str(top_int))
    if subset1_size is not None:
        cargs.append(str(subset1_size))
    if subset2_size is not None:
        cargs.append(str(subset2_size))
    ret = V2permOutputs(
        root=execution.output_file("."),
        file_a=execution.output_file(prefix + "_A") if (prefix is not None) else None,
        file_b=execution.output_file(prefix + "_B") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V2permOutputs",
    "V_2PERM_METADATA",
    "v_2perm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ESCAPE__METADATA = Metadata(
    id="f4258390d4b527039de0584cb728849422db04e3.boutiques",
    name="@escape-",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VEscapeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__escape_(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__escape_(
    help_: bool = False,
    runner: Runner | None = None,
) -> VEscapeOutputs:
    """
    A hypothetical command line tool for escaping sequences.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@escape-.html
    
    Args:
        help_: Display the help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VEscapeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ESCAPE__METADATA)
    cargs = []
    cargs.append("escape")
    if help_:
        cargs.append("-help")
    ret = VEscapeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VEscapeOutputs",
    "V__ESCAPE__METADATA",
    "v__escape_",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ROBUSTFOV_METADATA = Metadata(
    id="ba96504ba58594a00f41b8ac2107f15c773bd4a9.boutiques",
    name="robustfov",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class RobustfovOutputs(typing.NamedTuple):
    """
    Output object returned when calling `robustfov(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_roi_volume: OutputPathType
    """ROI volume output"""
    output_matrix_file: OutputPathType
    """Matrix output (ROI to full FOV)"""


def robustfov(
    input_file: InputPathType,
    runner: Runner | None = None,
) -> RobustfovOutputs:
    """
    Reduce FOV of image to remove lower head and neck.
    
    Author: University of Oxford (Mark Jenkinson)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/robustfov
    
    Args:
        input_file: Input image file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RobustfovOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ROBUSTFOV_METADATA)
    cargs = []
    cargs.append("robustfov")
    cargs.append("[OPTIONS]")
    cargs.append("-i")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.append("[-r")
    cargs.append("OUTPUT_IMAGE]")
    ret = RobustfovOutputs(
        root=execution.output_file("."),
        output_roi_volume=execution.output_file("[OUTPUT_IMAGE].nii.gz"),
        output_matrix_file=execution.output_file("[MATRIX_OUTPUT].txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ROBUSTFOV_METADATA",
    "RobustfovOutputs",
    "robustfov",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UBER_ALIGN_TEST_PY_METADATA = Metadata(
    id="ae56a4b4e64a9fd681065c6aac82cf43606fd468.boutiques",
    name="uber_align_test.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class UberAlignTestPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `uber_align_test_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def uber_align_test_py(
    runner: Runner | None = None,
) -> UberAlignTestPyOutputs:
    """
    Generate script to test anatomical/EPI alignment.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/uber_align_test.py.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UberAlignTestPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UBER_ALIGN_TEST_PY_METADATA)
    cargs = []
    cargs.append("uber_align_test.py")
    cargs.append("[COMMANDS]")
    cargs.append("[OPTIONS]")
    ret = UberAlignTestPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UBER_ALIGN_TEST_PY_METADATA",
    "UberAlignTestPyOutputs",
    "uber_align_test_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DWIEXTRACT_METADATA = Metadata(
    id="0671192cc8b8c9f31703ecba4585dd82f28ae520.boutiques",
    name="dwiextract",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class DwiextractFslgrad:
    """
    Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used.
    """
    bvecs: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    bvals: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-fslgrad")
        cargs.append(execution.input_file(self.bvecs))
        cargs.append(execution.input_file(self.bvals))
        return cargs


class DwiextractExportGradFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `DwiextractExportGradFsl | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    bvecs_path: OutputPathType
    """export the diffusion-weighted gradient table to files in FSL (bvecs /
    bvals) format"""
    bvals_path: OutputPathType
    """export the diffusion-weighted gradient table to files in FSL (bvecs /
    bvals) format"""


@dataclasses.dataclass
class DwiextractExportGradFsl:
    """
    export the diffusion-weighted gradient table to files in FSL (bvecs / bvals)
    format.
    """
    bvecs_path: str
    """export the diffusion-weighted gradient table to files in FSL (bvecs /
    bvals) format"""
    bvals_path: str
    """export the diffusion-weighted gradient table to files in FSL (bvecs /
    bvals) format"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-export_grad_fsl")
        cargs.append(self.bvecs_path)
        cargs.append(self.bvals_path)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> DwiextractExportGradFslOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `DwiextractExportGradFslOutputs`).
        """
        ret = DwiextractExportGradFslOutputs(
            root=execution.output_file("."),
            bvecs_path=execution.output_file(self.bvecs_path),
            bvals_path=execution.output_file(self.bvals_path),
        )
        return ret


@dataclasses.dataclass
class DwiextractImportPeEddy:
    """
    import phase-encoding information from an EDDY-style config / index file
    pair.
    """
    config: InputPathType
    """import phase-encoding information from an EDDY-style config / index file
    pair"""
    indices: InputPathType
    """import phase-encoding information from an EDDY-style config / index file
    pair"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-import_pe_eddy")
        cargs.append(execution.input_file(self.config))
        cargs.append(execution.input_file(self.indices))
        return cargs


@dataclasses.dataclass
class DwiextractConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class DwiextractOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dwiextract(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output image (diffusion-weighted volumes by default)."""
    export_grad_mrtrix: OutputPathType | None
    """export the diffusion-weighted gradient table to file in MRtrix format """
    export_grad_fsl: DwiextractExportGradFslOutputs | None
    """Outputs from `DwiextractExportGradFsl`."""


def dwiextract(
    input_: InputPathType,
    output: str,
    bzero: bool = False,
    no_bzero: bool = False,
    singleshell: bool = False,
    grad: InputPathType | None = None,
    fslgrad: DwiextractFslgrad | None = None,
    shells: list[float] | None = None,
    export_grad_mrtrix: str | None = None,
    export_grad_fsl: DwiextractExportGradFsl | None = None,
    import_pe_table: InputPathType | None = None,
    import_pe_eddy: DwiextractImportPeEddy | None = None,
    pe: list[float] | None = None,
    strides: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[DwiextractConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> DwiextractOutputs:
    """
    Extract diffusion-weighted volumes, b=0 volumes, or certain shells from a DWI
    dataset.
    
    
    
    References:
    
    .
    
    Author: David Raffelt (david.raffelt@florey.edu.au) and Thijs Dhollander
    (thijs.dhollander@gmail.com) and Robert E. Smith
    (robert.smith@florey.edu.au)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/dwiextract.html
    
    Args:
        input_: the input DW image.
        output: the output image (diffusion-weighted volumes by default).
        bzero: Output b=0 volumes (instead of the diffusion weighted volumes,\
            if -singleshell is not specified).
        no_bzero: Output only non b=0 volumes (default, if -singleshell is not\
            specified).
        singleshell: Force a single-shell (single non b=0 shell) output. This\
            will include b=0 volumes, if present. Use with -bzero to enforce\
            presence of b=0 volumes (error if not present) or with -no_bzero to\
            exclude them.
        grad: Provide the diffusion-weighted gradient scheme used in the\
            acquisition in a text file. This should be supplied as a 4xN text file\
            with each line is in the format [ X Y Z b ], where [ X Y Z ] describe\
            the direction of the applied gradient, and b gives the b-value in units\
            of s/mm^2. If a diffusion gradient scheme is present in the input image\
            header, the data provided with this option will be instead used.
        fslgrad: Provide the diffusion-weighted gradient scheme used in the\
            acquisition in FSL bvecs/bvals format files. If a diffusion gradient\
            scheme is present in the input image header, the data provided with\
            this option will be instead used.
        shells: specify one or more b-values to use during processing, as a\
            comma-separated list of the desired approximate b-values (b-values are\
            clustered to allow for small deviations). Note that some commands are\
            incompatible with multiple b-values, and will report an error if more\
            than one b-value is provided.\
            WARNING: note that, even though the b=0 volumes are never referred\
            to as shells in the literature, they still have to be explicitly\
            included in the list of b-values as provided to the -shell option!\
            Several algorithms which include the b=0 volumes in their\
            computations may otherwise return an undesired result.
        export_grad_mrtrix: export the diffusion-weighted gradient table to\
            file in MRtrix format.
        export_grad_fsl: export the diffusion-weighted gradient table to files\
            in FSL (bvecs / bvals) format.
        import_pe_table: import a phase-encoding table from file.
        import_pe_eddy: import phase-encoding information from an EDDY-style\
            config / index file pair.
        pe: select volumes with a particular phase encoding; this can be three\
            comma-separated values (for i,j,k components of vector direction) or\
            four (direction & total readout time).
        strides: specify the strides of the output data in memory; either as a\
            comma-separated list of (signed) integers, or as a template image from\
            which the strides shall be extracted and used. The actual strides\
            produced will depend on whether the output image format can support it.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DwiextractOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DWIEXTRACT_METADATA)
    cargs = []
    cargs.append("dwiextract")
    if bzero:
        cargs.append("-bzero")
    if no_bzero:
        cargs.append("-no_bzero")
    if singleshell:
        cargs.append("-singleshell")
    if grad is not None:
        cargs.extend([
            "-grad",
            execution.input_file(grad)
        ])
    if fslgrad is not None:
        cargs.extend(fslgrad.run(execution))
    if shells is not None:
        cargs.extend([
            "-shells",
            ",".join(map(str, shells))
        ])
    if export_grad_mrtrix is not None:
        cargs.extend([
            "-export_grad_mrtrix",
            export_grad_mrtrix
        ])
    if export_grad_fsl is not None:
        cargs.extend(export_grad_fsl.run(execution))
    if import_pe_table is not None:
        cargs.extend([
            "-import_pe_table",
            execution.input_file(import_pe_table)
        ])
    if import_pe_eddy is not None:
        cargs.extend(import_pe_eddy.run(execution))
    if pe is not None:
        cargs.extend([
            "-pe",
            ",".join(map(str, pe))
        ])
    if strides is not None:
        cargs.extend([
            "-strides",
            strides
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(input_))
    cargs.append(output)
    ret = DwiextractOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output),
        export_grad_mrtrix=execution.output_file(export_grad_mrtrix) if (export_grad_mrtrix is not None) else None,
        export_grad_fsl=export_grad_fsl.outputs(execution) if export_grad_fsl else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DWIEXTRACT_METADATA",
    "DwiextractConfig",
    "DwiextractExportGradFsl",
    "DwiextractExportGradFslOutputs",
    "DwiextractFslgrad",
    "DwiextractImportPeEddy",
    "DwiextractOutputs",
    "dwiextract",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PARSE_FS_LT_LOG_PY_METADATA = Metadata(
    id="4d3a9d80e34629170e64e5c99a643d72a1019166.boutiques",
    name="parse_fs_lt_log.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ParseFsLtLogPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `parse_fs_lt_log_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def parse_fs_lt_log_py(
    logfile: InputPathType,
    labels: list[str],
    show_orig: bool = False,
    show_all_orig: bool = False,
    verbosity: float | None = None,
    runner: Runner | None = None,
) -> ParseFsLtLogPyOutputs:
    """
    Parses FreeSurfer labeltable log file and retrieves labeltable indices.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/parse_fs_lt_log.py.html
    
    Args:
        logfile: Specify rank log file.
        labels: Specify a list of labels to search for.
        show_orig: Show original label indices.
        show_all_orig: Show all original label indices.
        verbosity: Specify verbosity level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ParseFsLtLogPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PARSE_FS_LT_LOG_PY_METADATA)
    cargs = []
    cargs.append("parse_fs_lt_log.py")
    cargs.append("-logfile")
    cargs.append(execution.input_file(logfile))
    cargs.append("-labels")
    cargs.extend([
        "-labels",
        *labels
    ])
    if show_orig:
        cargs.append("-show_orig")
    if show_all_orig:
        cargs.append("-show_all_orig")
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    ret = ParseFsLtLogPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PARSE_FS_LT_LOG_PY_METADATA",
    "ParseFsLtLogPyOutputs",
    "parse_fs_lt_log_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TRFIX_METADATA = Metadata(
    id="92993d180d096fd8c02ca5246a1f6bcc8544e559.boutiques",
    name="3dTRfix",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTrfixOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_trfix(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file_head: OutputPathType
    """Output dataset header file"""
    output_file_brik: OutputPathType
    """Output dataset brik file"""


def v_3d_trfix(
    input_file: InputPathType,
    prefix: str,
    tr_list: InputPathType | None = None,
    time_list: InputPathType | None = None,
    output_tr: float | None = None,
    runner: Runner | None = None,
) -> V3dTrfixOutputs:
    """
    Re-sample dataset with irregular time grid to regular time grid via linear
    interpolation.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTRfix.html
    
    Args:
        input_file: Input dataset.
        prefix: Prefix name for output dataset.
        tr_list: File of time gaps between sub-bricks in input dataset.
        time_list: File with times at each sub-brick in the input dataset.
        output_tr: TR value for output dataset (in seconds).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTrfixOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TRFIX_METADATA)
    cargs = []
    cargs.append("3dTRfix")
    cargs.append("-input")
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    cargs.append("-TRlist")
    if tr_list is not None:
        cargs.extend([
            "-TRlist",
            execution.input_file(tr_list)
        ])
    cargs.append("-TIMElist")
    if time_list is not None:
        cargs.extend([
            "-TIMElist",
            execution.input_file(time_list)
        ])
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.append("-TRout")
    if output_tr is not None:
        cargs.extend([
            "-TRout",
            str(output_tr)
        ])
    ret = V3dTrfixOutputs(
        root=execution.output_file("."),
        output_file_head=execution.output_file(prefix + "+orig.HEAD"),
        output_file_brik=execution.output_file(prefix + "+orig.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTrfixOutputs",
    "V_3D_TRFIX_METADATA",
    "v_3d_trfix",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_EXTREMA_METADATA = Metadata(
    id="559cda037dd05375e303c0e3226813b4366b2fa3.boutiques",
    name="SurfExtrema",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfExtremaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_extrema(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_grd: OutputPathType
    """Output file containing the scaled average gradient values."""
    output_ext: OutputPathType
    """Output file containing the nodes with maximum values."""


def surf_extrema(
    prefix: str,
    input_: InputPathType | None = None,
    hood: float | None = None,
    thresh: float | None = None,
    gthresh: float | None = None,
    gscale: typing.Literal["NONE", "LMEAN", "GMEAN"] | None = None,
    extype: typing.Literal["MAX", "MIN", "ABS"] | None = None,
    table: str | None = None,
    runner: Runner | None = None,
) -> SurfExtremaOutputs:
    """
    A program finding the local extrema in a dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfExtrema.html
    
    Args:
        prefix: Prefix for the output datasets.
        input_: Input dataset in which Extrema are to be identified.
        hood: Neighborhood radius (R) in mm. Default is 8 mm.
        thresh: Do not consider nodes with value less than this threshold.\
            Default is 0.
        gthresh: Do not consider nodes with gradient less than this threshold.\
            Default is 0.01.
        gscale: Scaling to apply to gradient computation.
        extype: Find maxima, minima, or extrema. Options are MAX (default),\
            MIN, ABS.
        table: Name of file in which to store a record of the extrema found.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfExtremaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_EXTREMA_METADATA)
    cargs = []
    cargs.append("SurfExtrema")
    if input_ is not None:
        cargs.extend([
            "-input",
            execution.input_file(input_)
        ])
    if hood is not None:
        cargs.extend([
            "-nbhd_rad",
            str(hood)
        ])
    if thresh is not None:
        cargs.extend([
            "-thresh",
            str(thresh)
        ])
    if gthresh is not None:
        cargs.extend([
            "-gthresh",
            str(gthresh)
        ])
    if gscale is not None:
        cargs.extend([
            "-gscale",
            gscale
        ])
    if extype is not None:
        cargs.extend([
            "-extype",
            extype
        ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if table is not None:
        cargs.extend([
            "-table",
            table
        ])
    ret = SurfExtremaOutputs(
        root=execution.output_file("."),
        output_grd=execution.output_file(prefix + ".grd"),
        output_ext=execution.output_file(prefix + ".ext"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_EXTREMA_METADATA",
    "SurfExtremaOutputs",
    "surf_extrema",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RTFEEDME_METADATA = Metadata(
    id="8ce4b7e02ec3a8cc807004a99f95d7b3f104ab5c.boutiques",
    name="rtfeedme",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class RtfeedmeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rtfeedme(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def rtfeedme(
    datasets: list[InputPathType],
    runner: Runner | None = None,
) -> RtfeedmeOutputs:
    """
    Test the real-time plugin by sending all the bricks in 'dataset' to AFNI.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/rtfeedme.html
    
    Args:
        datasets: List of datasets to send to AFNI, specified as paths to\
            dataset files. Multiple datasets can be specified.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RtfeedmeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RTFEEDME_METADATA)
    cargs = []
    cargs.append("rtfeedme")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in datasets])
    cargs.append("[DATASETS")
    cargs.append("...]")
    ret = RtfeedmeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RTFEEDME_METADATA",
    "RtfeedmeOutputs",
    "rtfeedme",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

XMAT_TOOL_PY_METADATA = Metadata(
    id="4b94463278ab4a58788f4e96808b817f9c5901eb.boutiques",
    name="xmat_tool.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class XmatToolPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `xmat_tool_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_fitts: OutputPathType
    """Output fit time series"""


def xmat_tool_py(
    no_gui: bool = False,
    load_xmat: InputPathType | None = None,
    load_1d: InputPathType | None = None,
    choose_cols: str | None = None,
    choose_nonzero_cols: bool = False,
    chrono: bool = False,
    cormat_cutoff: float | None = None,
    cosmat_cutoff: float | None = None,
    cosmat_motion: bool = False,
    verb: float | None = None,
    show_col_types: bool = False,
    show_conds: bool = False,
    show_cormat: bool = False,
    show_cormat_warnings: bool = False,
    show_cosmat: bool = False,
    show_cosmat_warnings: bool = False,
    show_fit_betas: bool = False,
    show_fit_ts: bool = False,
    show_xmat: bool = False,
    show_1d: bool = False,
    gui_plot_xmat_as_one: bool = False,
    runner: Runner | None = None,
) -> XmatToolPyOutputs:
    """
    A tool for evaluating an AFNI X-matrix.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/xmat_tool.py.html
    
    Args:
        no_gui: Do not start the GUI.
        load_xmat: Load the AFNI X-matrix.
        load_1d: Load the 1D time series.
        choose_cols: Select columns to fit against.
        choose_nonzero_cols: Select only non-zero columns.
        chrono: Apply options chronologically.
        cormat_cutoff: Set min cutoff for correlation matrix warnings.
        cosmat_cutoff: Set min cutoff for cosine matrix warnings.
        cosmat_motion: Include motion in cosine matrix warnings.
        verb: Set the verbose level. Valid levels are currently 0..5.
        show_col_types: Display columns by regressor types.
        show_conds: Display a list of condition numbers.
        show_cormat: Display the correlation matrix.
        show_cormat_warnings: Show correlation matrix warnings.
        show_cosmat: Display the cosine matrix.
        show_cosmat_warnings: Show cosine matrix warnings.
        show_fit_betas: Show fit betas.
        show_fit_ts: Show fit time series.
        show_xmat: Display general X-matrix information.
        show_1d: Display general 1D information.
        gui_plot_xmat_as_one: Plot Xmat columns on single axis.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `XmatToolPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(XMAT_TOOL_PY_METADATA)
    cargs = []
    cargs.append("xmat_tool.py")
    if no_gui:
        cargs.append("-no_gui")
    if load_xmat is not None:
        cargs.extend([
            "-load_xmat",
            execution.input_file(load_xmat)
        ])
    if load_1d is not None:
        cargs.extend([
            "-load_1D",
            execution.input_file(load_1d)
        ])
    if choose_cols is not None:
        cargs.extend([
            "-choose_cols",
            choose_cols
        ])
    if choose_nonzero_cols:
        cargs.append("-choose_nonzero_cols")
    if chrono:
        cargs.append("-chrono")
    if cormat_cutoff is not None:
        cargs.extend([
            "-cormat_cutoff",
            str(cormat_cutoff)
        ])
    if cosmat_cutoff is not None:
        cargs.extend([
            "-cosmat_cutoff",
            str(cosmat_cutoff)
        ])
    if cosmat_motion:
        cargs.append("-cosmat_motion")
    if verb is not None:
        cargs.extend([
            "-verb",
            str(verb)
        ])
    if show_col_types:
        cargs.append("-show_col_types")
    if show_conds:
        cargs.append("-show_conds")
    if show_cormat:
        cargs.append("-show_cormat")
    if show_cormat_warnings:
        cargs.append("-show_cormat_warnings")
    if show_cosmat:
        cargs.append("-show_cosmat")
    if show_cosmat_warnings:
        cargs.append("-show_cosmat_warnings")
    if show_fit_betas:
        cargs.append("-show_fit_betas")
    if show_fit_ts:
        cargs.append("-show_fit_ts")
    if show_xmat:
        cargs.append("-show_xmat")
    if show_1d:
        cargs.append("-show_1D")
    if gui_plot_xmat_as_one:
        cargs.append("-gui_plot_xmat_as_one")
    ret = XmatToolPyOutputs(
        root=execution.output_file("."),
        output_fitts=execution.output_file("fitts.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "XMAT_TOOL_PY_METADATA",
    "XmatToolPyOutputs",
    "xmat_tool_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SKULL_STRIP_TOUCH_UP_METADATA = Metadata(
    id="51b46d6e6f2f24c8b7822210349a52ed8df3d90e.boutiques",
    name="@SkullStrip_TouchUp",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSkullStripTouchUpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__skull_strip_touch_up(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_folder: OutputPathType
    """Output folder containing the touch-up results"""
    output_mask: OutputPathType
    """Output binary mask (if -mask_out flag is used)"""


def v__skull_strip_touch_up(
    prefix: str,
    brain_dataset: InputPathType,
    head_dataset: InputPathType,
    mask_out: bool = False,
    orig_dim: bool = False,
    runner: Runner | None = None,
) -> VSkullStripTouchUpOutputs:
    """
    Helper program to touch up failed skull stripping by resampling data, allowing
    manual edits, and outputting corrected data.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@SkullStrip_TouchUp.html
    
    Args:
        prefix: Output file and folder name.
        brain_dataset: Skull stripped data set to touch up.
        head_dataset: Whole head anatomical data set.
        mask_out: Output a binary mask in addition to actual data.
        orig_dim: Edit in the original image dimensions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSkullStripTouchUpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SKULL_STRIP_TOUCH_UP_METADATA)
    cargs = []
    cargs.append("@SkullStrip_TouchUp")
    cargs.append("-prefix")
    cargs.append(prefix)
    cargs.append("-brain")
    cargs.append(execution.input_file(brain_dataset))
    cargs.append("-head")
    cargs.append(execution.input_file(head_dataset))
    if mask_out:
        cargs.append("-mask_out")
    if orig_dim:
        cargs.append("-orig_dim")
    ret = VSkullStripTouchUpOutputs(
        root=execution.output_file("."),
        output_folder=execution.output_file(prefix + "_SS_touch_up"),
        output_mask=execution.output_file(prefix + "_mask.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSkullStripTouchUpOutputs",
    "V__SKULL_STRIP_TOUCH_UP_METADATA",
    "v__skull_strip_touch_up",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BACKEND_AVERAGE_DENSE_ROI_METADATA = Metadata(
    id="6b2e34efffe465091e8b7e6ed3878b97dc25248e.boutiques",
    name="backend-average-dense-roi",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class BackendAverageDenseRoiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `backend_average_dense_roi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def backend_average_dense_roi(
    index_list: str,
    out_file: str,
    runner: Runner | None = None,
) -> BackendAverageDenseRoiOutputs:
    """
    Connectome db backend command for cifti average dense roi.
    
    This command is probably not the one you are looking for, try
    -cifti-average-dense-roi. It takes the list of cifti files to average from
    standard input, and writes its output as little endian, 32-bit integer of
    row size followed by the row as 32-bit floats.
    
    Author: Washington University School of Medicin
    
    Args:
        index_list: comma separated list of cifti indexes to average.
        out_file: file to write the average row to.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BackendAverageDenseRoiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BACKEND_AVERAGE_DENSE_ROI_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-backend-average-dense-roi")
    cargs.append(index_list)
    cargs.append(out_file)
    ret = BackendAverageDenseRoiOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BACKEND_AVERAGE_DENSE_ROI_METADATA",
    "BackendAverageDenseRoiOutputs",
    "backend_average_dense_roi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_INFORMATION_METADATA = Metadata(
    id="8d554b2b29119c90a684a0c31a5ebeab511ca5b7.boutiques",
    name="surface-information",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceInformationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_information(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surface_information(
    surface_file: InputPathType,
    runner: Runner | None = None,
) -> SurfaceInformationOutputs:
    """
    Display information about a surface.
    
    Information about surface is displayed including vertices,
    triangles, bounding box, and spacing.
    
    Author: Washington University School of Medicin
    
    Args:
        surface_file: Surface for which information is displayed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceInformationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_INFORMATION_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-information")
    cargs.append(execution.input_file(surface_file))
    ret = SurfaceInformationOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_INFORMATION_METADATA",
    "SurfaceInformationOutputs",
    "surface_information",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL_TO_BORDER_METADATA = Metadata(
    id="6283a756b635b22e20fe2df1e148bdcf0d92d100.boutiques",
    name="label-to-border",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class LabelToBorderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label_to_border(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border_out: OutputPathType
    """the output border file"""


def label_to_border(
    surface: InputPathType,
    label_in: InputPathType,
    border_out: str,
    opt_placement_fraction: float | None = None,
    opt_column_column: str | None = None,
    runner: Runner | None = None,
) -> LabelToBorderOutputs:
    """
    Draw borders around labels.
    
    For each label, finds all edges on the mesh that cross the boundary of the
    label, and draws borders through them. By default, this is done on all
    columns in the input file, using the map name as the class name for the
    border.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to use for neighbor information.
        label_in: the input label file.
        border_out: the output border file.
        opt_placement_fraction: set how far along the edge border points are\
            drawn: fraction along edge from inside vertex (default 0.33).
        opt_column_column: select a single column: the column number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelToBorderOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_TO_BORDER_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-to-border")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(label_in))
    cargs.append(border_out)
    if opt_placement_fraction is not None:
        cargs.extend([
            "-placement",
            str(opt_placement_fraction)
        ])
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    ret = LabelToBorderOutputs(
        root=execution.output_file("."),
        border_out=execution.output_file(border_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL_TO_BORDER_METADATA",
    "LabelToBorderOutputs",
    "label_to_border",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AIV_METADATA = Metadata(
    id="f6a4a8c2d8a083ca2bf4a79422d1cd1d2d587d97.boutiques",
    name="aiv",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AivOutputs(typing.NamedTuple):
    """
    Output object returned when calling `aiv(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def aiv(
    input_images: list[InputPathType],
    verbose: bool = False,
    quiet: bool = False,
    title: str | None = None,
    port: float | None = None,
    pad: str | None = None,
    runner: Runner | None = None,
) -> AivOutputs:
    """
    AFNI Image Viewer program. Shows the 2D images on the command line in an
    AFNI-like image viewer.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/aiv.html
    
    Args:
        input_images: Input image files (e.g., img1.jpg, img2.bmp).
        verbose: Print out the image filenames for progress tracking.
        quiet: Run the program in quiet mode.
        title: Specify the window title.
        port: Listen to TCP/IP port for incoming images.
        pad: Pad all input images to be the same size.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AivOutputs`).
    """
    if port is not None and not (1024 <= port <= 65535): 
        raise ValueError(f"'port' must be between 1024 <= x <= 65535 but was {port}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(AIV_METADATA)
    cargs = []
    cargs.append("aiv")
    if verbose:
        cargs.append("-v")
    if quiet:
        cargs.append("-q")
    if title is not None:
        cargs.extend([
            "-title",
            title
        ])
    if port is not None:
        cargs.extend([
            "-p",
            str(port)
        ])
    if pad is not None:
        cargs.extend([
            "-pad",
            pad
        ])
    cargs.extend([execution.input_file(f) for f in input_images])
    ret = AivOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AIV_METADATA",
    "AivOutputs",
    "aiv",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_PROC_DWI_TO_DT_METADATA = Metadata(
    id="c9b03178bc0b3f7392ffeb60e5d57fcbd0a2ab68.boutiques",
    name="fat_proc_dwi_to_dt",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatProcDwiToDtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_proc_dwi_to_dt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Output files generated with the specified prefix."""


def fat_proc_dwi_to_dt(
    in_dwi: InputPathType,
    in_gradmat: InputPathType,
    prefix: str,
    runner: Runner | None = None,
) -> FatProcDwiToDtOutputs:
    """
    This program fits tensors and DT parameters, as well as the uncertainty of DT
    parameters needed for tractography.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/fat_proc_dwi_to_dt.html
    
    Args:
        in_dwi: 4D volume of N DWIs. Required.
        in_gradmat: Input text file of N gradient vectors or bmatrices.
        prefix: Set prefix for output DWI data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatProcDwiToDtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_PROC_DWI_TO_DT_METADATA)
    cargs = []
    cargs.append("fat_proc_dwi_to_dt")
    cargs.append("-in_dwi")
    cargs.append(execution.input_file(in_dwi))
    cargs.extend([
        "-in_col_matA | -in_col_matT | -in_col_vec | -in_row_vec",
        execution.input_file(in_gradmat)
    ])
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.append("[OPTIONAL_PARAMETERS]")
    ret = FatProcDwiToDtOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(prefix + "*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_PROC_DWI_TO_DT_METADATA",
    "FatProcDwiToDtOutputs",
    "fat_proc_dwi_to_dt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_OPEN_METADATA = Metadata(
    id="bc26cd888725fb54434b468b3ff940475336e2f9.boutiques",
    name="afni_open",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniOpenOutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_open(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def afni_open(
    files: list[InputPathType],
    runner: Runner | None = None,
) -> AfniOpenOutputs:
    """
    A program to open various AFNI/SUMA files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/afni_open.html
    
    Args:
        files: Input file(s) to be opened.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniOpenOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_OPEN_METADATA)
    cargs = []
    cargs.append("afni_open")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in files])
    cargs.append("[FILE2")
    cargs.append("...]")
    ret = AfniOpenOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_OPEN_METADATA",
    "AfniOpenOutputs",
    "afni_open",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FABBER_PET_METADATA = Metadata(
    id="46f5abb89eb6fa6d38c0da06d9a7cd2f69e1cd75.boutiques",
    name="fabber_pet",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FabberPetOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fabber_pet(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Directory containing output files including logfile"""
    param_names_file: OutputPathType
    """File containing the names of the model parameters if --dump-param-names
    is used"""
    model_fit_file: OutputPathType
    """4D volume containing the model prediction if --save-model-fit is used"""
    residuals_file: OutputPathType
    """4D volume containing the residuals if --save-residuals is used"""
    model_extras_file: OutputPathType
    """4D volume containing additional model-specific timeseries data if
    --save-model-extras is used"""
    mvn_file: OutputPathType
    """4D volume containing the final MVN distributions if --save-mvn is used"""
    mean_file: OutputPathType
    """4D volume containing the parameter means if --save-mean is used"""
    std_file: OutputPathType
    """4D volume containing the parameter standard deviations if --save-std is
    used"""
    var_file: OutputPathType
    """4D volume containing the parameter variances if --save-var is used"""
    zstat_file: OutputPathType
    """4D volume containing the parameter z-stats if --save-zstat is used"""
    noise_mean_file: OutputPathType
    """4D volume containing the noise means if --save-noise-mean is used"""
    noise_std_file: OutputPathType
    """4D volume containing the noise standard deviations if --save-noise-std is
    used"""
    free_energy_file: OutputPathType
    """4D volume containing the free energy if calculated and if
    --save-free-energy is used"""


def fabber_pet(
    runner: Runner | None = None,
) -> FabberPetOutputs:
    """
    Fabber Bayesian Model Fitting Tool.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fabber
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FabberPetOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FABBER_PET_METADATA)
    cargs = []
    cargs.append("fabber")
    cargs.append("[OPTIONS]")
    ret = FabberPetOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file("[OUTPUT]/*"),
        param_names_file=execution.output_file("[OUTPUT]/paramnames.txt"),
        model_fit_file=execution.output_file("[OUTPUT]/*_modelfit.nii.gz"),
        residuals_file=execution.output_file("[OUTPUT]/*_residuals.nii.gz"),
        model_extras_file=execution.output_file("[OUTPUT]/*_modextras.nii.gz"),
        mvn_file=execution.output_file("[OUTPUT]/*_mvn.nii.gz"),
        mean_file=execution.output_file("[OUTPUT]/*_mean.nii.gz"),
        std_file=execution.output_file("[OUTPUT]/*_std.nii.gz"),
        var_file=execution.output_file("[OUTPUT]/*_var.nii.gz"),
        zstat_file=execution.output_file("[OUTPUT]/*_zstat.nii.gz"),
        noise_mean_file=execution.output_file("[OUTPUT]/*_noisemean.nii.gz"),
        noise_std_file=execution.output_file("[OUTPUT]/*_noisestd.nii.gz"),
        free_energy_file=execution.output_file("[OUTPUT]/*_freeenergy.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FABBER_PET_METADATA",
    "FabberPetOutputs",
    "fabber_pet",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_MAKE_SCRIPT_AND_RST_PY_METADATA = Metadata(
    id="a90c364d18d38ed1214007f21054f30fed769d7f.boutiques",
    name="adjunct_make_script_and_rst.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctMakeScriptAndRstPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_make_script_and_rst_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    rst_file: OutputPathType
    """Generated RST documentation file."""
    script_file: OutputPathType
    """Generated script file."""
    output_directory: OutputPathType
    """Output directory in Sphinx tree."""


def adjunct_make_script_and_rst_py(
    input_script: InputPathType,
    prefix_rst: str,
    prefix_script: str,
    reflink: str,
    execute_script: bool = False,
    runner: Runner | None = None,
) -> AdjunctMakeScriptAndRstPyOutputs:
    """
    Program to take a script with some special markup and turn it into both an RST
    page and a script for the online Sphinx documentation.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/adjunct_make_script_and_rst.py.html
    
    Args:
        input_script: Input script file with special markup.
        prefix_rst: Output filename including any path of the RST/Sphinx file.\
            Must include file extension '.rst'.
        prefix_script: Output filename of the script file. Should include file\
            extension such as '.tcsh'.
        reflink: A string tag that will serve as the subdirectory name holding\
            images for the given demo, and the RST internal reference label.
        execute_script: Flag to create the RST and script files, and also\
            execute the script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctMakeScriptAndRstPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_MAKE_SCRIPT_AND_RST_PY_METADATA)
    cargs = []
    cargs.append("adjunct_make_script_and_rst.py")
    cargs.append("--input")
    cargs.append(execution.input_file(input_script))
    cargs.append("--prefix_rst")
    cargs.extend([
        "--prefix_rst",
        prefix_rst
    ])
    cargs.append("--prefix_script")
    cargs.extend([
        "--prefix_script",
        prefix_script
    ])
    cargs.append("--reflink")
    cargs.extend([
        "--reflink",
        reflink
    ])
    if execute_script:
        cargs.append("--execute_script")
    ret = AdjunctMakeScriptAndRstPyOutputs(
        root=execution.output_file("."),
        rst_file=execution.output_file(prefix_rst),
        script_file=execution.output_file(prefix_script),
        output_directory=execution.output_file(prefix_rst + "/media/" + reflink),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_MAKE_SCRIPT_AND_RST_PY_METADATA",
    "AdjunctMakeScriptAndRstPyOutputs",
    "adjunct_make_script_and_rst_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GENERATE_BRAIN_METADATA = Metadata(
    id="8e55c9d531ee7cf50058bbf211e40f0bf566dddc.boutiques",
    name="generate_brain",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class GenerateBrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `generate_brain(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmented_image: OutputPathType | None
    """Segmented output image"""
    bias_field: OutputPathType | None
    """Estimated bias field"""
    corrected_image: OutputPathType | None
    """Bias-corrected image"""
    pve_maps: OutputPathType | None
    """Partial volume estimation maps"""
    probability_maps: OutputPathType | None
    """Individual probability maps for each class"""


def generate_brain(
    infile: InputPathType,
    class_number: float | None = 3,
    iter_number: float | None = 4,
    lowpass_extent: float | None = 20,
    image_type: float | None = 1,
    init_seg_smoothness: float | None = 0.02,
    segments_flag: bool = False,
    init_priors: InputPathType | None = None,
    alt_priors: list[InputPathType] | None = None,
    nopve_flag: bool = False,
    bias_field_flag: bool = False,
    bias_corrected_flag: bool = False,
    no_bias_flag: bool = False,
    channels_number: float | None = 1,
    output_basename: str | None = None,
    use_priors_flag: bool = False,
    seg_init_iters: float | None = 15,
    mixel_smoothness: float | None = 0.3,
    fixed_iters: float | None = 4,
    seg_smoothness: float | None = 0.1,
    verbose_flag: bool = False,
    help_flag: bool = False,
    manual_seg: InputPathType | None = None,
    prob_maps_flag: bool = False,
    runner: Runner | None = None,
) -> GenerateBrainOutputs:
    """
    FMRIB's Automated Segmentation Tool.
    
    Author: University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FAST
    
    Args:
        infile: Input image(s) for segmentation.
        class_number: Number of tissue-type classes; default=3.
        iter_number: Number of main-loop iterations during bias-field removal;\
            default=4.
        lowpass_extent: Bias field smoothing extent (FWHM) in mm; default=20.
        image_type: Type of image 1=T1, 2=T2, 3=PD; default=T1.
        init_seg_smoothness: Initial segmentation spatial smoothness (during\
            bias field estimation); default=0.02.
        segments_flag: Outputs a separate binary image for each tissue type.
        init_priors: Initialise using priors; you must supply a FLIRT transform.
        alt_priors: Alternative prior images (must specify three images).
        nopve_flag: Turn off PVE (partial volume estimation).
        bias_field_flag: Output estimated bias field.
        bias_corrected_flag: Output bias-corrected image.
        no_bias_flag: Do not remove bias field.
        channels_number: Number of input images (channels); default 1.
        output_basename: Output basename.
        use_priors_flag: Use priors throughout; you must also set the -a option.
        seg_init_iters: Number of segmentation-initialisation iterations;\
            default=15.
        mixel_smoothness: Spatial smoothness for mixeltype; default=0.3.
        fixed_iters: Number of main-loop iterations after bias-field removal;\
            default=4.
        seg_smoothness: Segmentation spatial smoothness; default=0.1.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display help message.
        manual_seg: Filename containing intensities.
        prob_maps_flag: Outputs individual probability maps.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GenerateBrainOutputs`).
    """
    if alt_priors is not None and (len(alt_priors) != 3): 
        raise ValueError(f"Length of 'alt_priors' must be 3 but was {len(alt_priors)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(GENERATE_BRAIN_METADATA)
    cargs = []
    cargs.append("fast")
    if class_number is not None:
        cargs.extend([
            "-n",
            str(class_number)
        ])
    if iter_number is not None:
        cargs.extend([
            "-I",
            str(iter_number)
        ])
    if lowpass_extent is not None:
        cargs.extend([
            "-l",
            str(lowpass_extent)
        ])
    if image_type is not None:
        cargs.extend([
            "-t",
            str(image_type)
        ])
    if init_seg_smoothness is not None:
        cargs.extend([
            "-f",
            str(init_seg_smoothness)
        ])
    if segments_flag:
        cargs.append("-g")
    if init_priors is not None:
        cargs.extend([
            "-a",
            execution.input_file(init_priors)
        ])
    if alt_priors is not None:
        cargs.extend([
            "-A",
            *[execution.input_file(f) for f in alt_priors]
        ])
    if nopve_flag:
        cargs.append("--nopve")
    if bias_field_flag:
        cargs.append("-b")
    if bias_corrected_flag:
        cargs.append("-B")
    if no_bias_flag:
        cargs.append("-N")
    if channels_number is not None:
        cargs.extend([
            "-S",
            str(channels_number)
        ])
    if output_basename is not None:
        cargs.extend([
            "-o",
            output_basename
        ])
    if use_priors_flag:
        cargs.append("-P")
    if seg_init_iters is not None:
        cargs.extend([
            "-W",
            str(seg_init_iters)
        ])
    if mixel_smoothness is not None:
        cargs.extend([
            "-R",
            str(mixel_smoothness)
        ])
    if fixed_iters is not None:
        cargs.extend([
            "-O",
            str(fixed_iters)
        ])
    if seg_smoothness is not None:
        cargs.extend([
            "-H",
            str(seg_smoothness)
        ])
    if verbose_flag:
        cargs.append("-v")
    if help_flag:
        cargs.append("-h")
    if manual_seg is not None:
        cargs.extend([
            "-s",
            execution.input_file(manual_seg)
        ])
    if prob_maps_flag:
        cargs.append("-p")
    cargs.append(execution.input_file(infile))
    ret = GenerateBrainOutputs(
        root=execution.output_file("."),
        segmented_image=execution.output_file(output_basename + "_seg.nii.gz") if (output_basename is not None) else None,
        bias_field=execution.output_file(output_basename + "_bias.nii.gz") if (output_basename is not None) else None,
        corrected_image=execution.output_file(output_basename + "_restore.nii.gz") if (output_basename is not None) else None,
        pve_maps=execution.output_file(output_basename + "_pve*.nii.gz") if (output_basename is not None) else None,
        probability_maps=execution.output_file(output_basename + "_prob*.nii.gz") if (output_basename is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GENERATE_BRAIN_METADATA",
    "GenerateBrainOutputs",
    "generate_brain",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_MACAQUE_DEMO_REST_METADATA = Metadata(
    id="10a53ef31c17c86242b50300d965aee0155a9142.boutiques",
    name="@Install_MACAQUE_DEMO_REST",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallMacaqueDemoRestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_macaque_demo_rest(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    readme_file: OutputPathType
    """Details of the demo archive after download."""


def v__install_macaque_demo_rest(
    wget_flag: bool = False,
    curl_flag: bool = False,
    lite_version_flag: bool = False,
    runner: Runner | None = None,
) -> VInstallMacaqueDemoRestOutputs:
    """
    Installs the demo archive for AFNI's resting state FMRI macaque-analysis demo.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_MACAQUE_DEMO_REST.html
    
    Args:
        wget_flag: Use wget to download archive. Script chooses by default with\
            preference for curl.
        curl_flag: Use curl to download archive. Script chooses by default with\
            preference for curl.
        lite_version_flag: Download a version of the Demo in which the EPIs\
            have been truncated to 75 points each. This makes the download size\
            less than half of the original, and means the afni_proc.py processing\
            will run faster.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallMacaqueDemoRestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_MACAQUE_DEMO_REST_METADATA)
    cargs = []
    cargs.append("Install_MACAQUE_DEMO_REST")
    if wget_flag:
        cargs.append("-wget")
    if curl_flag:
        cargs.append("-curl")
    if lite_version_flag:
        cargs.append("-lite_version")
    ret = VInstallMacaqueDemoRestOutputs(
        root=execution.output_file("."),
        readme_file=execution.output_file("README.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallMacaqueDemoRestOutputs",
    "V__INSTALL_MACAQUE_DEMO_REST_METADATA",
    "v__install_macaque_demo_rest",
]
